# AUTHORS.md

This file lists the authors, maintainers, and contributors for the
[sdfascii][] project.

## Authors
- Matthew Rankin

## Maintainers
- None at this time.

## Contributors
- None at this time.

[sdfascii]: https://github.com/questrail/sdfascii
